package de.mhoehme.android.partyfinder;

import android.os.Handler;
import org.osmdroid.DefaultResourceProxyImpl;
import org.osmdroid.ResourceProxy;
import org.osmdroid.tileprovider.MapTileProviderArray;
import org.osmdroid.tileprovider.MapTileProviderBase;
import org.osmdroid.tileprovider.modules.ArchiveFileFactory;
import org.osmdroid.tileprovider.modules.IArchiveFile;
import org.osmdroid.tileprovider.modules.MapTileFileArchiveProvider;
import org.osmdroid.tileprovider.modules.MapTileModuleProviderBase;
import org.osmdroid.tileprovider.tilesource.ITileSource;
import org.osmdroid.tileprovider.tilesource.XYTileSource;
import org.osmdroid.tileprovider.util.SimpleRegisterReceiver;
import org.osmdroid.util.GeoPoint;
import org.osmdroid.views.MapView;

import android.app.Activity;
import android.os.Bundle;

import java.io.File;


/**
 * Display a custom map, such as Stamen Watercolor.
 * The tiles must be provided in a zip file.
 */
public class CustomMapActivity extends Activity {


    private static final String TAG = SimpleMapActivity.class.getName();


    private static final String TILE_ARCHIVE = "/sdcard/osmdroid/SanktAugustinStamenWatercolor.zip";


    /**
     * Called when the activity is first created.
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);


        // (1) Get a custom tile provider
        MapTileProviderBase tileProvider = getTileProviders(new String[]{TILE_ARCHIVE});


        // (2) Create a MapView and pass the custom tile provider
        final MapView mapView = new MapView(this, 256, new DefaultResourceProxyImpl(this), tileProvider);
        mapView.setUseDataConnection(false);

        mapView.setBuiltInZoomControls(true);

        mapView.getController().setZoom(12);
        setContentView(mapView);



        new Handler().postDelayed(new Runnable() {
            @Override
            public void run() {

                mapView.getController().setCenter(new GeoPoint(50.780155, 7.182144));

            }
        }, 1000); // 200

    }


    /**
     * Creates a custom tile provider for offline tiles stored in a zipfile.
     *
     * The zipfile must have the following structure:
     *
     * //name/zoom/area/*.png
     *
     * To create custom tiles, you can use a tool such as Maperative.
     * After generating the tiles,
     * (1) go to the Maperative home directory
     * (2) mv Tiles <YourName>
     * (3) zip -r <YourName>.zip <YourName>
     */
    private MapTileProviderArray getTileProviders(String[] zipArchives) {

        ITileSource tileSource = new XYTileSource(
                "SanktAugustinStamenWatercolor",                // Path name
                ResourceProxy.string.offline_mode,
                8, 15,                                          // available zoom levels (min, max)
                256, ".png",                                    // tile size and image type
                new String[]{ "http://127.0.0.1" } );


        IArchiveFile[] archiveFiles = new IArchiveFile[zipArchives.length];
        for (int i = 0; i < zipArchives.length; i++) {
            archiveFiles[i] = ArchiveFileFactory.getArchiveFile(new File(zipArchives[i]));
        }


        MapTileModuleProviderBase moduleProvider = new MapTileFileArchiveProvider(
                new SimpleRegisterReceiver(this),
                tileSource,
                archiveFiles);

        MapTileModuleProviderBase[] providers = new MapTileModuleProviderBase[] { moduleProvider };


        MapTileProviderArray mapProvider = new MapTileProviderArray(tileSource, null, providers);
        mapProvider.setUseDataConnection(false);

        return mapProvider;
    }

}
