/*
        Disclaimer: The code is provided as it is, with no warranties.
        Mag Hoehme <java@mhoehme.de>, 2014

*/
package de.mhoehme.android.partyfinder;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import org.osmdroid.tileprovider.tilesource.TileSourceFactory;
import org.osmdroid.util.GeoPoint;
import org.osmdroid.views.MapView;
import org.osmdroid.views.overlay.MinimapOverlay;
import org.osmdroid.views.overlay.ScaleBarOverlay;
import org.osmdroid.views.overlay.mylocation.MyLocationNewOverlay;


/**
 * Activity that uses MyLocationNewOverlay.
 *
 * Shortcomings:
 * {@link org.osmdroid.views.overlay.mylocation.MyLocationNewOverlay} does not make use of the last known location.
 * Therefore the user's location appears only after the first fix has been obtained.
 *
 */
public class MyLocationMapActivity extends Activity {

    private static final String TAG = PartyMapActivity.class.getName();


    // http://wiki.openstreetmap.org/wiki/Zoom_levels
    private static final int INITIAL_ZOOM = 14;


    private MyLocationNewOverlay myLocationOverlay = null;


    /**
     * Called when the activity is first created.
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.map_layout);


        final MapView mapView = (MapView) findViewById(R.id.openmapview);
        mapView.setClickable          (true);
        mapView.setBuiltInZoomControls(true);
        mapView.setTileSource         (TileSourceFactory.MAPNIK);

        // Using offline data only
        // Tutorial for creating offlline data: http://www.haakseth.com/?p=30
        // mapView.setUseDataConnection  (true); // use cached data only...

        mapView.getController().setZoom(INITIAL_ZOOM);

        // -- ScaleBarOverlay -----------------------------------------

        // (1) create overlay
        ScaleBarOverlay myScaleBarOverlay = new ScaleBarOverlay(this);

        // (2) add Overlay to the map
        mapView.getOverlays().add(myScaleBarOverlay);


        // -- MinimapOverlay  -----------------------------------------

        // (1) Create and initialize overlay
        MinimapOverlay miniMapOverlay = new MinimapOverlay(this, mapView.getTileRequestCompleteHandler());
        miniMapOverlay.setZoomDifference(4);
        miniMapOverlay.setHeight(100);
        miniMapOverlay.setWidth(100);

        // (2) add overlay
        mapView.getOverlays().add(miniMapOverlay);



        // -- MyLocationOverlay -----------------------------------------

        // http://android-coding.blogspot.de/2012/06/example-of-implementing-openstreetmap.html
        // http://android-coding.blogspot.de/2012/07/display-user-location-by-adding.html
        // http://android-coding.blogspot.de/2012/07/osmdroid-mapview-to-follow-user.html
        myLocationOverlay = new MyLocationNewOverlay(this, mapView);

        // https://developers.google.com/maps/documentation/android/v1/reference/com/google/android/maps/MyLocationOverlay#runOnFirstFix%28java.lang.Runnable%29

        // Queues a runnable to be executed as soon as we have a location fix.
        // If we already have a fix, we'll execute the runnable immediately and
        // return true. If not, we'll hang on to the runnable and return false;
        // as soon as we get a location fix, we'll run it in in a new thread.
        //
        // mho: runs as soon as the position changes
        myLocationOverlay.runOnFirstFix(new Runnable() {
            public void run() {

                final GeoPoint myLocation = myLocationOverlay.getMyLocation();

                if (myLocation != null) {
                    Log.d(TAG, "[runOnFirstFix.run] location = " + myLocation.getLatitude() + " " + myLocation.getLongitude()
                            + " (" + myLocation + ")");

                    mapView.getController().animateTo(myLocation);
                }
            }
        });

        mapView.getOverlays().add(myLocationOverlay);
    }


    @Override
    protected void onResume() {
        super.onResume();
        myLocationOverlay.enableMyLocation();
        myLocationOverlay.enableFollowLocation();
    }


    @Override
    protected void onPause() {
        super.onPause();
        // switch off to save energy
        myLocationOverlay.disableMyLocation();
        myLocationOverlay.disableFollowLocation();
    }
}
