/*
        Disclaimer: The code is provided as it is, with no warranties.
        Mag Hoehme <java@mhoehme.de>, 2014

*/
package de.mhoehme.android.partyfinder;

import android.app.*;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import de.mhoehme.android.partyfinder.services.PartyAlarmService;


/**
 * Simple Activity for alarming the user when a party is detected.
 *
 *
 * https://github.com/yyl/Tracking-map-on-android
 *
 */
public class PartyAlarmActivity extends Activity {

    private static final String TAG = PartyAlarmActivity.class.getName();


    private static final long   INTERVAL         = 1 * 60 * 1000;
    private static final int    DEFAULT_DISTANCE = 100;


    private PendingIntent       pendingIntent;

    private int                 distance = DEFAULT_DISTANCE; // metres



    /**
     * Called when the activity is first created.
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.party_alarm_layout);

        toggleButtons(true);

        ((EditText) findViewById(R.id.party_distance)).setText(""+distance);
    }




    public void onClick(View view) {
        if (view.getId() == R.id.start_button) {

            Log.d(TAG, "[onClick] Party alarm STARTED ---------------------");

            toggleButtons(false);

            startMyService();


        } else if (view.getId() == R.id.stop_button) {

            Log.d(TAG, "[onClick] Party alarm STOPPED ---------------------");

            toggleButtons(true);

            stopMyService();
        }
    }


    /**
     * Register an AlarmManager that starts the PartyAlarmService every few minutes.
     */
    private void startMyService() {

        String text =  ((TextView) findViewById(R.id.party_distance)).getText().toString();
        try {

            distance = Integer.parseInt(text);

        } catch (NumberFormatException nfe) {
            Log.d(TAG, "[startMyService] Not a number: "+ text);
            distance = DEFAULT_DISTANCE;
        }


        // (1) Create a pending intent
        Intent intent = new Intent(getApplicationContext(), PartyAlarmService.class);
        intent.putExtra(PartyAlarmService.DISTANCE, distance);
        pendingIntent = PendingIntent.getService(getApplicationContext(), 2222, intent,
                PendingIntent.FLAG_CANCEL_CURRENT);


        // (2) Register an AlarmManager
        AlarmManager alarmManager = (AlarmManager) getSystemService(Context.ALARM_SERVICE);
        alarmManager.setInexactRepeating(AlarmManager.RTC_WAKEUP, System.currentTimeMillis(), INTERVAL, pendingIntent);
    }


    private void stopMyService() {
        AlarmManager alarmManager = (AlarmManager) getSystemService(Context.ALARM_SERVICE);
        alarmManager.cancel(pendingIntent);

        // unregisterReceiver(partyAlarmReceiver);

    }



    private void toggleButtons(boolean start) {
        findViewById(R.id.start_button).setEnabled(start);
        findViewById(R.id.start_button).setActivated(start);
        findViewById(R.id.stop_button).setEnabled(! start);
        findViewById(R.id.stop_button).setActivated(! start);
    }
}
