/*
        Disclaimer: The code is provided as it is, with no warranties.
        Mag Hoehme <java@mhoehme.de>, 2014

*/
package de.mhoehme.android.partyfinder.model;

import android.location.Location;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

/**
 * Utility class serving as a data provider.
 * In a real-life app, the data should come over the Internet and be cached in a database.
 */
public class DataProvider {

    private static final String TAG = DataProvider.class.getName();


    /*

    St. Augustin
        echo "geo fix 7.182144 50.780155" | telnet localhost 5554

    Llucamajor
        echo "geo fix 2.856445 39.461078" | telnet localhost 5554
     */

    private static final List<Place> PARTIES = new ArrayList<>();


    static {

        PARTIES.add(new Place("Paguera",          "Beach party",                            39.537056, 2.451344));
        PARTIES.add(new Place("Porto Petro",      "Call +08/15-4711",                       39.361189, 3.208705));
        PARTIES.add(new Place("Ibiza",            "Welcome to the bonfire",                 39.027218, 1.532758));

        PARTIES.add(new Place("Pleiser Park",     "Coding unterm Sternenzelt",              50.775279, 7.200579));
        PARTIES.add(new Place("Siegufer",         "Open-Air Coding mit Lagerfeuerromantik", 50.782619, 7.212488));
        PARTIES.add(new Place("8bar",             "Disco/Event",                            50.793966, 7.203598));

        PARTIES.add(new Place("Pflanzen Breuer",  "Kostenlos Hanf abzugeben",               50.782309, 7.177875));
        PARTIES.add(new Place("Schulzentrum Niederpleis", "Rocken bis zum Morgengrauen",    50.774602, 7.212421));
        PARTIES.add(new Place("Tanke",            "Nachschub holen",                        50.776651, 7.194043));
        PARTIES.add(new Place("Campus",           "Ausschlafen",                            50.780750, 7.181860));

    }


    /**
     *
     * @param location    central location
     * @param maxDistance distance to the given location in meters
     * @return            list of places within a given distance
     */
    public static List<Place> getParties(Location location, int maxDistance) {
        ArrayList<Place> parties = new ArrayList<>();

        Location myLocation = new Location("");          // provider name is unecessary
        myLocation.setLatitude(location.getLatitude());
        myLocation.setLongitude(location.getLongitude());

        Location targetLocation = new Location("");

        for (Place party : PARTIES) {

            targetLocation.setLatitude (party.getLatitude() );
            targetLocation.setLongitude(party.getLongitude());

            float distanceInMeters =  targetLocation.distanceTo(myLocation);

            if (distanceInMeters <= maxDistance) {
                parties.add(party);
            }
        }

        Log.d(TAG, "[getParties] at "+location+": "+parties);

        return parties;
    }
}
