/*
        Disclaimer: The code is provided as it is, with no warranties.
        Mag Hoehme <java@mhoehme.de>, 2014

*/
package de.mhoehme.android.partyfinder.services;

import android.app.*;
import android.content.Context;
import android.content.Intent;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationManager;
import android.util.Log;
import de.mhoehme.android.partyfinder.PartyMapActivity;
import de.mhoehme.android.partyfinder.R;
import de.mhoehme.android.partyfinder.model.DataProvider;
import de.mhoehme.android.partyfinder.model.Place;

import java.util.List;

/**
 * Created by tux on 16.08.14.
 */
public class PartyAlarmService extends IntentService {

    private static final String TAG = PartyAlarmService.class.getName();


    public static final String DISTANCE = "DISTANCE";


    private int                distance = 100; // metres


    /**
     * Required for the AndroidManifest.xml
     */
    public PartyAlarmService() {
        super ("PartyAlarmService");
    }

    /**
     * Creates an IntentService. Invoked by your subclass's constructor.

     *
     * @param name Used to name the worker thread, important only for debugging.
     */
    public PartyAlarmService(String name) {
        super(name);
    }



    @Override
    public void onHandleIntent(Intent intent) {

        if (intent.getExtras().containsKey(DISTANCE)) {
            distance = intent.getExtras().getInt(DISTANCE);
        }

        Log.d(TAG, "[onHandleIntent] distance = "+distance);

        LocationManager locationManager = (LocationManager) getSystemService(Context.LOCATION_SERVICE);

        String provider = locationManager.getBestProvider(new Criteria(), true);

        Location location = locationManager.getLastKnownLocation(provider);

        checkParties(location);
    }



    private void checkParties(Location location) {
        List<Place> parties = DataProvider.getParties(location, distance);
        if (parties.size() > 0) {
            Log.d(TAG, "[checkParties] "+parties);

            displayNotification(parties);

        }
    }




    protected void displayNotification(List<Place> parties) {
        Log.d(TAG, "[displayNotification] parties = "+parties);
        for (Place party : parties) {

            Intent intent = new Intent(this, PartyMapActivity.class);
            PendingIntent partyIntent = PendingIntent.getActivity(this, 0, intent, 0);

            Notification notification = new Notification.Builder(this)
                    .setContentTitle(getString(R.string.party_alarm_title))
                    .setContentText(party.getTitle() + ": " + party.getInfo() +
                            " [ " + party.getLatitude() + " " + party.getLongitude() + "]")
                    .setSmallIcon(R.drawable.bluefrog_small)
                    .setContentIntent(partyIntent)
                    .addAction(R.drawable.bluefrog_small, getString(R.string.show_map), partyIntent).build();
            NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            // hide the notification after it has been selected
            notification.flags |= Notification.FLAG_AUTO_CANCEL;

            notificationManager.notify(0, notification);
        }
    }




    // -----------------------------------------------------------------------------------------------
    // http://stackoverflow.com/questions/14478179/background-service-with-location-listener-in-android
    //
    // Algorithm telling which location is best.


    private static final long INTERVAL = 5 * 1000;
    private Location lastLocation;



    protected boolean isBetterLocation(Location location, Location currentBestLocation) {
        if (currentBestLocation == null) {
            // A new location is always better than no location
            return true;
        }

        // Check whether the new location fix is newer or older
        long timeDelta = location.getTime() - currentBestLocation.getTime();
        boolean isSignificantlyNewer = timeDelta > INTERVAL;
        boolean isSignificantlyOlder = timeDelta < -INTERVAL;
        boolean isNewer = timeDelta > 0;

        // If it's been more than two minutes since the current location, use the new location
        // because the user has likely moved
        if (isSignificantlyNewer) {
            return true;
            // If the new location is more than two minutes older, it must be worse
        } else if (isSignificantlyOlder) {
            return false;
        }

        // Check whether the new location fix is more or less accurate
        int accuracyDelta = (int) (location.getAccuracy() - currentBestLocation.getAccuracy());
        boolean isLessAccurate = accuracyDelta > 0;
        boolean isMoreAccurate = accuracyDelta < 0;
        boolean isSignificantlyLessAccurate = accuracyDelta > 200;

        // Check if the old and new location are from the same provider
        boolean isFromSameProvider = isSameProvider(location.getProvider(),
                currentBestLocation.getProvider());

        // Determine location quality using a combination of timeliness and accuracy
        if (isMoreAccurate) {
            return true;
        } else if (isNewer && !isLessAccurate) {
            return true;
        } else if (isNewer && !isSignificantlyLessAccurate && isFromSameProvider) {
            return true;
        }
        return false;
    }



    /** Checks whether two providers are the same */
    private boolean isSameProvider(String provider1, String provider2) {
        if (provider1 == null) {
            return provider2 == null;
        }
        return provider1.equals(provider2);
    }

}